/*******************************************************************************
*  Filter.h - Configure the program
*
*  Berzerk/
*
*  Part of the BuckoSoft Network Monitor
*  Copyright(c) 2008 - BuckoSoft, Inc.
*
*  http://git.buckosoft.com/gitweb/?p=Berzerk.git;a=history;f=Berzerk/Filter.h
*
*  With which we monitor a log file and perform appropriate action.
\*******************************************************************************/

#ifndef	_FILTER_H_
#define	_FILTER_H_

#include <string>
#include <list>
using namespace std;

#include <boost/regex.hpp>
using namespace boost;

//namespace berzerk { class Berzerk; }

class Filter
{
  public:
	Filter();
  public:
	~Filter();

	static bool	parseFile(PCSTR fileName);

	void	setName(const string& name);
	const string& getName();

	void	setTrap(const string& trap);
	const string& getTrap();

	void	setLogFile(const string& logFile);
	const string& getLogFile();

	void	setWeight(int weight);
	int		getWeight();
	bool	readFile(ifstream& ifs);

	const	list<string>& getMatchPatterns();
	const	string& getIPPattern();
	void	prepareRegexp();

	//void	setBerzerk(Berzerk* berzerk);
	static void	setDEBUG(int value);
	static void				setRootDirectory(const string& dir);
	static const string&	getRootDirectory();

	list<regex*> 	patterns;

  private:
	string			name;
	list<string>	matchPatterns;
	string			ipExtractPattern;
	string			logFile;
	string			trap;
	int				weight;

	static int		DEBUG;
	static string	rootDirectory;
};

inline const list<string>& Filter::getMatchPatterns() { return(matchPatterns); }
inline const string& Filter::getIPPattern() { return(ipExtractPattern); }

inline void Filter::setLogFile(const string& lf) { logFile = lf; }
inline const string& Filter::getLogFile() { return(logFile); }

inline void Filter::setName(const string& n) { name = n; }
inline const string& Filter::getName() { return(name); }

inline void Filter::setTrap(const string& t) { trap = t; }
inline const string& Filter::getTrap() { return(trap); }

inline void Filter::setWeight(int w) { weight = w; }
inline int Filter::getWeight() { return(weight); }

inline void Filter::setDEBUG(int level) { DEBUG = level; }
inline void Filter::setRootDirectory(const string& dir) { rootDirectory = dir; }
inline const string& Filter::getRootDirectory() { return(rootDirectory); }

#endif		// _FILTER_H_
