/*******************************************************************************
*  TestFilter.h - Exorcise Regexpes against a log
*
*  Berzerk/
*
*  Part of the BuckoSoft Network Monitor
*  Copyright(c) 2016 - BuckoSoft, Inc.
*
*  http://git.buckosoft.com/gitweb/?p=Berzerk.git;a=history;f=Berzerk/TestFilter.cpp
*
\*******************************************************************************/

#include "stdafx.h"
#include "../config.h"
#include <iostream>
#include <fstream>
#include <boost/foreach.hpp>

#include "server/urlencode.h"
#include "WebHandler.h"
#include "TestFilter.h"

using namespace std;

namespace berzerk {

PCSTR	s_matched	= "Matched";
PCSTR	s_line		= "Line";

TestFilter::TestFilter(const LogFile* _logFile, const string& _regexp, const string& _regexpIP) {
	logFile = _logFile;
	regexp = _regexp;
	regexpIP = _regexpIP;
	maxLines = 50;
	hasError = false;
}

///////////////////////////////////////////////////////////////////////////////
bool	TestFilter::run() {
	char		buff[4096];

//	matchedLines.push_back(TLine("Hi momBad text c++ha how are you? 1.2.3.4", 6, 8, 34, 7));
//	matchedLines.push_back(TLine("Hi momBad text c++ha how are you? 1.2.3.4 abcd", 6, 8, 34, 7));
//	matchedLines.push_back(TLine("Hi dad 5.6.7.8 Bad text", 15, 8, 7, 7));
//	return(true);
	ifstream file;
	file.open(logFile->name.c_str() , ifstream::in);
	if (!file.good()) {
		error = "Error opening file: '" + logFile->name + "'";
		return(false);
	}
	string s;
	regex rex;
	rex.assign(regexp);
	regex rexip;
	rexip.assign(regexpIP);
	boost::match_results<std::string::const_iterator> what;
	while (!file.fail()) {
		file.getline(buff, 4095);
		if (file.fail())
			break;
		s = buff;
		if (regex_search(s, what, rex)) {
			if (DEBUG > 1)
				cout << "matched: " << buff << endl;
			cout << "what[0]" << what[0] << endl;
			int match_start = s.find(what[0]);
			if (match_start < 0)
				match_start = 0;
			int match_length = what[0].length();
			int ip_start = 0;
			int ip_length = 0;
			if (regex_search(s, what, rexip)) {
				ip_start = s.find(what[0]);
				ip_length = what[0].length();
			}
			matchedLines.push_back(TLine(s, match_start, match_length, ip_start, ip_length));
			if (maxLines && matchedLines.size() >= maxLines)
				break;
		}
	}
	file.close();
	return(true);
}

///////////////////////////////////////////////////////////////////////////////
void	TestFilter::output(http::server::reply& rep) {
	rep.content = s_xml_preamble;
	rep.content += xmlToken(s_matched);
	if (!error.empty()) {
		string s = "<span class=\"mle\">";
		s += error;
		s += "</span>";
		rep.content += toXml(s_line, urlencode(s), 1);
	} else {
		BOOST_FOREACH(TLine tline, matchedLines) {
			string s = tline.line;
			if (!tline.length && !tline.ipLength) {
				s = tline.line;
			} else if (tline.length && !tline.ipLength) {
				s = tline.line.substr(0, tline.start);
				s += "<span class=\"mlm\">";
				s += tline.line.substr(tline.start, tline.length);
				s += "</span>";
				s += tline.line.substr(tline.start+tline.length);
			} else if (tline.ipLength && !tline.length) {
				s = tline.line.substr(0, tline.ipStart);
				s += "<span class=\"mli\">";
				s += tline.line.substr(tline.ipStart, tline.ipLength);
				s += "</span>";
				s += tline.line.substr(tline.ipStart+tline.ipLength);
			} else {
				if (tline.ipStart < tline.start) {
					s = "";
					if (tline.ipStart > 0)
						s = tline.line.substr(0, tline.ipStart);
					s += "<span class=\"mli\">";
					s += tline.line.substr(tline.ipStart, tline.ipLength);
					s += "</span>";
					if (tline.start > tline.ipStart + tline.ipLength)
						s += tline.line.substr(tline.ipStart + tline.ipLength, tline.start-(tline.ipStart + tline.ipLength));
					s += "<span class=\"mlm\">";
					s += tline.line.substr(tline.start, tline.length);
					s += "</span>";
					if (tline.start + tline.length < tline.line.length())
						s += tline.line.substr(tline.start + tline.length);
				} else {
					s = "";
					if (tline.start > 0)
						s = tline.line.substr(0, tline.start);
					s += "<span class=\"mlm\">";
					s += tline.line.substr(tline.start, tline.length);
					s += "</span>";
					if (tline.ipStart > tline.start + tline.length)
						s += tline.line.substr(tline.start + tline.length, tline.ipStart-(tline.start + tline.length));
					s += "<span class=\"mli\">";
					s += tline.line.substr(tline.ipStart, tline.ipLength);
					s += "</span>";
					if (tline.ipStart + tline.ipLength < tline.line.length())
						s += tline.line.substr(tline.ipStart + tline.ipLength);

				}
			}
			rep.content += toXml(s_line, urlencode(s), 1);
		}
	}
	rep.content += xmlTokenE(s_matched);

}

} // namespace berzerk
