/*******************************************************************************
*  TestFilter.h - Exorcise Regexpes against a log
*
*  Berzerk/
*
*  Part of the BuckoSoft Network Monitor
*  Copyright(c) 2016 - BuckoSoft, Inc.
*
*  http://git.buckosoft.com/gitweb/?p=Berzerk.git;a=history;f=Berzerk/TestFilter.h
*
\*******************************************************************************/

#ifndef _BERZERK_TESTFILTER_H_
#define _BERZERK_TESTFILTER_H_

#include <string>
#include "server/reply.hpp"

#include "Berzerk.h"

namespace berzerk {
class TLine {
  public:
	TLine();
	TLine(const string& line, int match_start = 0, int match_length = 0, int ip_start = 0, int ip_length = 0);
	string	line;
	int		start;		// match start
	int		length;		// match length
	int		ipStart;	// ip match start
	int		ipLength;	// ip match length
};

class TestFilter {
  public:
	TestFilter(const LogFile* logFile, const string& regexp, const string& regexpIP);
	void	setMaxLines(int i);
	bool	run();
	void	output(http::server::reply& rep);

  private:
	const LogFile*	logFile;
	list<TLine>	matchedLines;

	string			regexp;
	string			regexpIP;
	int				maxLines;
	bool			hasError;
	string			error;		// if !empty, then there was an error.
};

inline void TestFilter::setMaxLines(int i) { maxLines = i; }

inline TLine::TLine() { start = 0; length = 0; ipStart = 0; ipLength = 0;}
inline TLine::TLine(const string& line, int match_start, int match_length, int ip_start, int ip_length) {
	this->line = line; this->start = match_start; this->length = match_length;
	ipStart = ip_start; ipLength = ip_length;
}
}	// namespace berzerk
#endif /* _BERZERK_TESTFILTER_H_ */
